package domain.model;

import domain.DomainException;

public class Tankstation {
    private String gemeente;
    private double prijs;
    private final String naam;

    public Tankstation(String naam, String gemeente, double prijs) {
        setGemeente(gemeente);
        setPrijs(prijs);
        if (naam == null || naam.trim().isEmpty() || naam.trim().length() < 3)
            throw new DomainException("Geen geldige naam");
        this.naam = naam;
    }

    public String getGemeente() {
        return gemeente;
    }

    public void setGemeente(String gemeente) {
        if (gemeente == null || gemeente.trim().isEmpty())
            throw new DomainException("Geen geldige gemeente");
        this.gemeente = gemeente;
    }

    public double getPrijs() {
        return prijs;
    }

    public void setPrijs(double prijs) {
        if (prijs<0)
            throw new DomainException("Geen geldige prijs");
        this.prijs = prijs;
    }

    public String getNaam() {
        return naam;
    }

    /**
     * Geeft kostprijs van gegeven hoeveelheid
     * @throws DomainException indien gegeven hoeveelheid negatief is
     */
    public double berekenKost(double hoeveelheid) {
        if (hoeveelheid<0)
            throw new DomainException("Hoeveelheid moet positief zijn");
        return getPrijs()*hoeveelheid;
    }
}
